@@ -8,7 +8,11 @@
  moved out from world.c                                                                                                               
  Peter Beerli 2000, Seattle
  beerli@genetics.washington.edu
- $Id: lrt.c,v 1.10 2001/05/17 05:46:48 beerli Exp $
+ 
+ Copyright 2001 Peter Beerli and Joseph Felsenstein
+
+$Id: lrt.c,v 1.13 2001/07/25 19:27:24 beerli Exp $
+
 -------------------------------------------------------*/
 #define SICK_VALUE    -1
 #include "migration.h"
@@ -33,17 +37,18 @@
 #endif
 
 void print_lratio_test (world_fmt * world, long *Gmax);
-void test_loci_like (nr_fmt * nr, double *param0, 
-		     double *param1, long df, long zeros, 
-		     long loci, world_fmt * world, 
-		     long *maxwhich, long maxnum, 
+void test_loci_like (nr_fmt * nr, double *param0,
+		     double *param1, long df, long zeros,
+		     long loci, world_fmt * world,
+		     long *maxwhich, long maxnum,
 		     boolean withhead, char *this_string1,
 		     char *this_string2);
-long set_test_param (double *param, char *strp, world_fmt * world, 
-		     long lrline, long locus, long *maxwhich, 
+long set_test_param (double *param, char *strp, world_fmt * world,
+		     long lrline, long locus, long *maxwhich,
 		     long *maxnum, long *zeros);
 
-boolean mywhitespace (char ch)
+boolean
+mywhitespace (char ch)
 {
   if (!(ch == ',' || ch == '\0' || ch == '\n' || ch == ';'))
     {
@@ -57,7 +62,7 @@ void
 print_lratio_test (world_fmt * world, long *Gmax)
 {
   long c;
-  long r,  locus;
+  long r, locus;
   long df;
   long zeros;
   int header;
@@ -66,9 +71,9 @@ print_lratio_test (world_fmt * world, long *Gmax)
   double *param1;
   long *maxwhich;
   long maxnum = 0;
-  long rep = !world->options->replicate ? 0 : 
-    (world->options->replicatenum == 0 ? 
-     world->options->lchains : world->options->replicatenum); 
+  long rep = !world->options->replicate ? 0 :
+    (world->options->replicatenum == 0 ?
+     world->options->lchains : world->options->replicatenum);
   long repstop = world->repstop;
   param0 = (double *) calloc (1, sizeof (double) * (world->numpop2 + 1));
   param1 = (double *) calloc (1, sizeof (double) * (world->numpop2 + 1));
@@ -88,82 +93,84 @@ print_lratio_test (world_fmt * world, long *Gmax)
       else
 	create_apg0 (nr->apg0[0][locus], nr, &world->atl[0][locus]);
     }
-  if(world->loci>1)
+  if (world->loci > 1)
     {
-      locus=world->loci;
+      locus = world->loci;
       rep = 0;
     }
   else
     {
-      locus=0;
+      locus = 0;
     }
   PAGEFEEDWORLD;
-  for(c=0; c<world->options->lratio->counter; c++)
+  for (c = 0; c < world->options->lratio->counter; c++)
     {
       header = (c == 0) ? HEADER : NOHEADER;
       if (world->options->lratio->data[c].type == MLE)
 	{
-	  memcpy(param1,world->atl[rep][locus].param,
-		 sizeof(double)*world->numpop2);
-	  df = set_test_param (param0, 
-			       world->options->lratio->data[c].value1, 
+	  memcpy (param1, world->atl[rep][locus].param,
+		  sizeof (double) * world->numpop2);
+	  df = set_test_param (param0,
+			       world->options->lratio->data[c].value1,
 			       world, 0, -1, maxwhich, &maxnum, &zeros);
 	  test_loci_like (nr, param0, param1,
-			  df, zeros, world->loci, world, maxwhich, 
-			  maxnum, header, 
-			  world->options->lratio->data[c].value1,
-			  NULL);
+			  df, zeros, world->loci, world, maxwhich,
+			  maxnum, header,
+			  world->options->lratio->data[c].value1, NULL);
 	}
-      else /*arbitrary*/
+      else			/*arbitrary */
 	{
-	  df=set_test_param(param0,world->options->lratio->data[c].value1, 
-			    world, 0, -1, maxwhich, &maxnum, &zeros);
-	  df=set_test_param(param1,world->options->lratio->data[c].value2, 
-			    world, 0, -1, maxwhich, &maxnum, &zeros);
-	  test_loci_like (nr, param0, param1, 
-			  df, zeros, world->loci, world, maxwhich, 
-			  maxnum, HEADER, 
+	  df = set_test_param (param0, world->options->lratio->data[c].value1,
+			       world, 0, -1, maxwhich, &maxnum, &zeros);
+	  df = set_test_param (param1, world->options->lratio->data[c].value2,
+			       world, 0, -1, maxwhich, &maxnum, &zeros);
+	  test_loci_like (nr, param0, param1,
+			  df, zeros, world->loci, world, maxwhich,
+			  maxnum, HEADER,
 			  world->options->lratio->data[c].value1,
 			  world->options->lratio->data[c].value2);
 	}
       //      fprintf (world->outfile, "Remember: Tests based on a single locus may not be valid\n");
     }
-  fflush(world->outfile);
+  fflush (world->outfile);
   free (param0);
   free (param1);
   free (maxwhich);
   destroy_nr (nr, world);
 }
 
-void tell_chiprob2(char *message, double zeros, double df, double chi)
+void
+tell_chiprob2 (char *message, double zeros, double df, double chi)
 {
-  if(chi>chiboundary (zeros, df-zeros,0.001))
+  if (chi > chiboundary (zeros, df - zeros, 0.001))
     {
-      if(chi>chiboundary (zeros, df-zeros,0.0001))
-	strcpy(message,"<0.0001");
+      if (chi > chiboundary (zeros, df - zeros, 0.0001))
+	strcpy (message, "<0.0001");
       else
-	strcpy(message,"<0.001 ");
+	strcpy (message, "<0.001 ");
     }
   else
     {
-      if(chi>chiboundary (zeros, df-zeros,0.01))
-        strcpy(message,"<0.01  ");
+      if (chi > chiboundary (zeros, df - zeros, 0.01))
+	strcpy (message, "<0.01  ");
       else
 	{
-	  if(chi>chiboundary (zeros, df-zeros,0.05))
-	    strcpy(message,"<0.05  ");
+	  if (chi > chiboundary (zeros, df - zeros, 0.05))
+	    strcpy (message, "<0.05  ");
 	  else
-	    strcpy(message,">0.05  ");
+	    strcpy (message, ">0.05  ");
 	}
     }
 }
 
 
 void
-test_locus_like (nr_fmt * nr, double *param0, double *param1, long df, long zeros, long locus, world_fmt * world, long *maxwhich, long maxnum, boolean withhead, char *this_string)
+test_locus_like (nr_fmt * nr, double *param0, double *param1, long df,
+		 long zeros, long locus, world_fmt * world, long *maxwhich,
+		 long maxnum, boolean withhead, char *this_string)
 {
   char *teststat, temp[LRATIO_STRINGS];
-  double like1, like0, testval, chiprob;
+  double like1, like0, testval, chiprob, chiprob2;
   int length;
   char tmp[LRATIO_STRINGS];
   long zi, i, part1len = 1, part2len = 1;
@@ -201,26 +208,26 @@ test_locus_like (nr_fmt * nr, double *param0, double *param1, long df, long zero
 		z++;
 	    }
 	}
-      nr->profilenum=w;
-      maximize(param0, world, nr, PROFILE, world->repkind);
+      nr->profilenum = w;
+      maximize (param0, world, nr, PROFILE, world->repkind);
       like0 = nr->llike;
       normd = nr->normd;
-      memcpy(param0,world->param0,sizeof(double)*nr->partsize);
+      memcpy (param0, world->param0, sizeof (double) * nr->partsize);
     }
   else
     {
-      set_logparam(lparam0,param0, elem);
+      set_logparam (lparam0, param0, elem);
       fill_helper (&helper, param0, lparam0, world, nr);
       like0 = calc_loci_like (&helper, FALSE, FALSE);
     }
-  set_logparam(lparam1,param1, elem);
+  set_logparam (lparam1, param1, elem);
   fill_helper (&helper, param1, lparam1, world, nr);
   like1 = calc_loci_like (&helper, param1, lparam1);
   testval = -2. * (like0 - like1);
   chiprob = probchi (df, testval);
-  tell_chiprob2(message, zeros, df, testval);
-  //  chiprob2 = probchiboundary(testval, zeros, 
-  //		     df - zeros);
+  //tell_chiprob2(message, zeros, df, testval);
+  chiprob2 = probchiboundary (testval, zeros, df);
+  sprintf (message, " %f ", chiprob2);
   teststat = (char *) calloc (1, sizeof (char) * LRATIO_STRINGS);
   length = MAX (0, 5 - sprintf (tmp, "%i", ((int) param0[0])));
   sprintf (teststat, "Loc%3li: %.*f", locus, length, param0[0]);
@@ -270,13 +277,19 @@ test_locus_like (nr_fmt * nr, double *param0, double *param1, long df, long zero
 
   if (withhead)
     {
-      fprintf (world->outfile, "==============================================================================\n");
+      fprintf (world->outfile,
+	       "==============================================================================\n");
       fprintf (world->outfile, "Likelihood ratio tests\n");
-      fprintf (world->outfile, "==============================================================================\n");
+      fprintf (world->outfile,
+	       "==============================================================================\n");
       fprintf (world->outfile, "Over all loci\n");
-      fprintf (world->outfile, "[Theta values are on the diagonal of the Migration matrix,\nmigration rates are specified as Theta*M]\n");
+      fprintf (world->outfile,
+	       "[Theta values are on the diagonal of the Migration matrix,\nmigration rates are specified as Theta*M]\n");
       part1len = MAX (part1len, part2len - part1len);
-      fprintf (world->outfile, "%*.*s           %-10.10s   %-3.3s   %-4.4s %-5.5s\n", (int) part1len, (int) part1len, " ", "Test value", "Df", "Prob", "Prob*");
+      fprintf (world->outfile,
+	       "%*.*s           %-10.10s   %-3.3s   %-4.4s %-5.5s\n",
+	       (int) part1len, (int) part1len, " ", "Test value", "Df",
+	       "Prob", "Prob*");
       for (i = 0; i < part1len + 35; i++)
 	fputc ('-', world->outfile);
       fprintf (world->outfile, "\n");
@@ -286,23 +299,27 @@ test_locus_like (nr_fmt * nr, double *param0, double *param1, long df, long zero
   else
     sprintf (temp, "%10.2f", testval);
   fprintf (world->outfile, "You entered\n[%s]\n", this_string);
-  fprintf (world->outfile, "%s %s -2(%6.3f-%6.3f)=%11.11s %3li %8.5f %s\n", teststat, spacer, like0, like1, temp, df, chiprob, message);
+  fprintf (world->outfile, "%s %s -2(%6.3f-%6.3f)=%11.11s %3li %8.5f %s\n",
+	   teststat, spacer, like0, like1, temp, df, chiprob, message);
   free (teststat);
   free (lparam0);
   free (lparam1);
   free (saveparam0);
   free (which);
-  free(message);
+  free (message);
 }
 
 //remember: param0 is the parameterset to test and
 // NOT the parameterset from migrate.
 void
-test_loci_like (nr_fmt * nr, double *param0, double *param1, long df, long zeros, long loci, world_fmt * world, long *maxwhich, long maxnum, boolean withhead, char *this_string1, char *this_string2)
+test_loci_like (nr_fmt * nr, double *param0, double *param1, long df,
+		long zeros, long loci, world_fmt * world, long *maxwhich,
+		long maxnum, boolean withhead, char *this_string1,
+		char *this_string2)
 {
 
   char *teststat, temp[LRATIO_STRINGS];
-  double like1, like0, testval, chiprob;
+  double like1, like0, testval, chiprob, chiprob2;
   int length;
   char tmp[LRATIO_STRINGS];
   long i, j, g = 0, part1len = 1, part2len = 1;
@@ -349,25 +366,26 @@ test_loci_like (nr_fmt * nr, double *param0, double *param1, long df, long zeros
 		z++;
 	    }
 	}
-      nr->profilenum=w;
-      maximize(param0, world, nr, PROFILE, world->repkind);
+      nr->profilenum = w;
+      maximize (param0, world, nr, PROFILE, world->repkind);
       like0 = nr->llike;
       normd = nr->normd;
-      memcpy(param0,world->param0,sizeof(double)*nr->partsize);
+      memcpy (param0, world->param0, sizeof (double) * nr->partsize);
     }
   else
     {
-      set_logparam(lparam0,param0, elem);
+      set_logparam (lparam0, param0, elem);
       fill_helper (&helper, param0, lparam0, world, nr);
       like0 = calc_loci_like (&helper, param0, lparam0);
     }
-  set_logparam(lparam1,param1, elem);
+  set_logparam (lparam1, param1, elem);
   fill_helper (&helper, param1, lparam1, world, nr);
   like1 = calc_loci_like (&helper, param1, lparam1);
   testval = -2. * (like0 - like1);
   chiprob = probchi (df, testval);
-  tell_chiprob2(message, zeros, df, testval);
-  //chiprob2 = probchiboundary(testval, zeros, df - zeros);
+  //tell_chiprob2(message, zeros, df, testval);
+  chiprob2 = probchiboundary (testval, zeros, df);
+  sprintf (message, " %f ", chiprob2);
   teststat = (char *) calloc (1, sizeof (char) * LRATIO_STRINGS);
   length = MAX (0, 5 - sprintf (tmp, "%i", ((int) param0[0])));
   sprintf (teststat, "H0:%.*f", length, param0[0]);
@@ -387,7 +405,8 @@ test_loci_like (nr_fmt * nr, double *param0, double *param1, long df, long zeros
       if ((i + 1) % world->numpop == 0)
 	strcat (teststat, "\n  ");
     }
-  sprintf (temp, "=assumed to be equal to=    -2(%6.3f-%6.3f)=", like0, like1);
+  sprintf (temp, "=assumed to be equal to=    -2(%6.3f-%6.3f)=", like0,
+	   like1);
   strcat (teststat, temp);
   if (testval > 10000 && chiprob < EPSILON)
     sprintf (temp, ">10000.00  %3li %8.5f %s\n", df, chiprob, message);
@@ -422,13 +441,19 @@ test_loci_like (nr_fmt * nr, double *param0, double *param1, long df, long zeros
 
   if (withhead)
     {
-      fprintf (world->outfile, "==============================================================================\n");
+      fprintf (world->outfile,
+	       "==============================================================================\n");
       fprintf (world->outfile, "Likelihood ratio tests\n");
-      fprintf (world->outfile, "==============================================================================\n");
+      fprintf (world->outfile,
+	       "==============================================================================\n");
       fprintf (world->outfile, "Over all loci\n");
-      fprintf (world->outfile, "[Theta values are on the diagonal of the Migration matrix,\nmigration rates are specified as Theta*M]\n");
+      fprintf (world->outfile,
+	       "[Theta values are on the diagonal of the Migration matrix,\nmigration rates are specified as Theta*M]\n");
       part1len = MAX (part1len, part2len - part1len);
-      fprintf (world->outfile, "%*.*s      %-10.10s   %-3.3s   %-4.4s %-5.5s\n", (int) part1len, (int) part1len, " ", "Test value", "Df", "Prob", "Prob*");
+      fprintf (world->outfile,
+	       "%*.*s      %-10.10s   %-3.3s   %-4.4s %-5.5s\n",
+	       (int) part1len, (int) part1len, " ", "Test value", "Df",
+	       "Prob", "Prob*");
       for (i = 0; i < part1len + 35; i++)
 	fputc ('-', world->outfile);
       fprintf (world->outfile, "\n");
@@ -440,29 +465,29 @@ test_loci_like (nr_fmt * nr, double *param0, double *param1, long df, long zeros
     sprintf (temp, "%10.2f", testval);
   fprintf (world->outfile, "You entered\n[%s]\n", this_string1);
   //fprintf (world->outfile, "%s %s -2(%6.3f-%6.3f)=%11.11s %3li %8.5f %s\n", teststat, spacer, like0, like1, temp, df, chiprob, message);
-  fprintf (world->
-outfile, "%s\n", teststat);
+  fprintf (world->outfile, "%s\n", teststat);
   free (teststat);
-  free(lparam0);
-  free(lparam1);
+  free (lparam0);
+  free (lparam1);
   free (saveparam0);
   free (which);
-  free(message);
+  free (message);
 }
 
 
 long
-set_test_param (double *param, char *strp, world_fmt * world, long lrline, long locus, long *maxwhich, long *maxnum, long *zeros)
+set_test_param (double *param, char *strp, world_fmt * world, long lrline,
+		long locus, long *maxwhich, long *maxnum, long *zeros)
 {
   long i = 0, z = 0, zi = 0, zz = 0, zzz = 0, df = 0;
   long offset = 0, limit = 0, pop, pop1, pop2;
   long numpop = world->numpop;
   char *tmp, *ss, *paramtype;
   double *meanparam, mean;
-long repstop = !world->options->replicate ? 0 : 
-    (world->options->replicatenum == 0 ? 
+  long repstop = !world->options->replicate ? 0 :
+    (world->options->replicatenum == 0 ?
      world->options->lchains : world->options->replicatenum);
- *zeros=0; 
+  *zeros = 0;
   ss = (char *) calloc (1, sizeof (char) * LINESIZE);
   tmp = (char *) calloc (1, sizeof (char) * LINESIZE);
   paramtype = (char *) calloc (1, sizeof (char) * world->numpop2);
@@ -511,7 +536,8 @@ long repstop = !world->options->replicate ? 0 :
 		{
 		  mean = 0.0;
 		  offset = (zi >= world->numpop) ? world->numpop : 0;
-		  limit = (zi >= world->numpop) ? world->numpop2 : world->numpop;
+		  limit =
+		    (zi >= world->numpop) ? world->numpop2 : world->numpop;
 		  for (zz = offset; zz < limit; zz++)
 		    mean += meanparam[zz];
 		  mean /= limit - offset;
@@ -530,7 +556,8 @@ long repstop = !world->options->replicate ? 0 :
 		{
 		  mean = 0.0;
 		  offset = (zi >= world->numpop) ? world->numpop : 0;
-		  limit = (zi >= world->numpop) ? world->numpop2 : world->numpop;
+		  limit =
+		    (zi >= world->numpop) ? world->numpop2 : world->numpop;
 		  if (offset < numpop)
 		    {
 		      paramtype[zi] = '-';
@@ -569,7 +596,9 @@ long repstop = !world->options->replicate ? 0 :
 	      else
 		{
 		  paramtype[zi] = '-';
-		  param[zi] = (meanparam[zi] + meanparam[mm2m (pop2, pop1, world->numpop)]) / 2.;
+		  param[zi] =
+		    (meanparam[zi] +
+		     meanparam[mm2m (pop2, pop1, world->numpop)]) / 2.;
 		  z++;
 		}
 	      break;
@@ -584,14 +613,17 @@ long repstop = !world->options->replicate ? 0 :
 	      else
 		{
 		  paramtype[zi] = '+';
-		  param[zi] = (meanparam[zi] * meanparam[pop2] + meanparam[mm2m (pop2, pop1, world->numpop)] * meanparam[pop1]) / 2.;
+		  param[zi] =
+		    (meanparam[zi] * meanparam[pop2] +
+		     meanparam[mm2m (pop2, pop1, world->numpop)] *
+		     meanparam[pop1]) / 2.;
 		  z++;
 		}
 	      break;
 	    default:
 	      paramtype[zi] = '+';
 	      df++;
-	      if(tmp[0]=='0')
+	      if (tmp[0] == '0')
 		(*zeros)++;
 	      param[zi] = MAX (atof (tmp), SMALLEST_THETA);
 	      z++;
@@ -612,4 +644,3 @@ long repstop = !world->options->replicate ? 0 :
   free (tmp);
   return df;
 }
-
