@@ -14,7 +14,10 @@
                                                                                                                
  Peter Beerli, started 1997, Seattle
  beerli@genetics.washington.edu
-$Id: main.c,v 1.69 2001/05/17 05:46:48 beerli Exp $
+
+Copyright 2001 Peter Beerli and Joseph Felsenstein
+
+$Id: main.c,v 1.75 2001/07/25 19:27:24 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
 #include "definitions.h"
@@ -61,7 +64,8 @@ tpool_t heating_pool;
 #endif
 
 char appl[20];
-longer seed;
+long *seed;
+long *newseed;
 
 int setup_locus (long locus, world_fmt * world, option_fmt * options,
 		 data_fmt * data);
@@ -83,10 +87,12 @@ void heating_prepare2 (world_fmt ** universe, int usize);
 long replicate_number (option_fmt * options, long chain, char type,
 		       long replicate);
 
-void combine_loci (char type, option_fmt * options, world_fmt * world, long *Gmax);
+void combine_loci (char type, option_fmt * options, world_fmt * world,
+		   long *Gmax);
 
-void run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
-		  int usize, long *outfilepos, long *Gmax);
+void run_sampler (option_fmt * options, data_fmt * data,
+		  world_fmt ** universe, int usize, long *outfilepos,
+		  long *Gmax);
 
 void run_loci (world_fmt ** universe, int usize, option_fmt * options,
 	       data_fmt * data, tpool_t * heating_pool, long maxreplicate,
@@ -144,6 +150,9 @@ void print_heating_progress2 (FILE * file, worldoption_fmt * options,
 			      double acc_h, double acc_w, double acc_c,
 			      long hot, long warm, long cold);
 
+void get_treedata (world_fmt * world, option_fmt * options);
+void get_mighistdata (world_fmt * world, option_fmt * options);
+
 /* Functions ++++++++++++++++++++++++++++++++++++++++++++++++*/
 /*--------------------------------------------
    main program 
@@ -170,6 +179,10 @@ main (int argc, char **argv)
   myID = MASTER;
   numcpu = 1;
 #endif
+  // random number seed global inits
+  seed = malloc (sizeof (long) * 3);
+  newseed = malloc (sizeof (long) * 3);
+  // 
   universe = (world_fmt **) calloc (HEATED_CHAIN_NUM, sizeof (world_fmt *));
   this_string = (char *) calloc (1, sizeof (char) * 256);
   strcpy (appl, "Migrate");
@@ -198,8 +211,6 @@ main (int argc, char **argv)
   else
     {
       broadcast_options_worker (options);
-      //options->verbose=FALSE;
-      //      options->progress=FALSE;
       options->writelog = FALSE;
       options->menu = FALSE;
     }
@@ -228,7 +239,8 @@ main (int argc, char **argv)
     }
   // with MPI: the workers stay here much longer than the Master
   combine_loci (type, options, EARTH, &Gmax);	// multilocus MLE
-
+  // gather the treedata (1) into sumfile or from worker nodes
+  get_treedata (EARTH, options);
   /* printing of data ------------------------------------------- */
 #ifdef MPI
   if (myID == MASTER)
@@ -239,7 +251,7 @@ main (int argc, char **argv)
 #ifdef MPI
     }
 #endif
-  if(options->aic || (EARTH->options->lratio->counter > 0))
+  if (options->aic || (EARTH->options->lratio->counter > 0))
     {
 #ifdef MPI
       if (myID == MASTER)
@@ -247,37 +259,45 @@ main (int argc, char **argv)
 #endif
 	  if (EARTH->options->lratio->counter > 0)
 	    print_lratio_test (EARTH, &Gmax);
-	  if(options->aic)
-	    akaike_information(EARTH, &Gmax);
+	  if (options->aic)
+	    akaike_information (EARTH, &Gmax);
 #ifdef MPI
 	}
 #endif
     }
-  print_mighist (EARTH);      
+  if (myID == MASTER)
+    {
+#ifdef MPI
+      get_mighistdata (EARTH, options);
+#endif
+      print_mighist (EARTH);
+    }
   /* print UEP probabilities ------------------------------------ */
 #ifdef UEP
   if (options->uep)
     analyze_uep (EARTH);
 #endif
   /* profile tables --------------------------------------------- */
-#ifdef SLOWNET /*DOES NOT WORK YET*/
-  if(myID == MASTER)
-    {
-      mpi_send_stop (EARTH); // stop workers
-    }
-  distribute_treedata(); //distributes to all numcpu all the treesummaries
-  profile_tables (options, EARTH, &Gmax); 
-#else
-#ifdef MPI  /*WORKS*/
+#ifdef SLOWNET			/*DOES NOT WORK YET */
+  // if there are many loci but only few parameters to estimate
+  // this will be still slow and saturating the network
+  // with parameter requests may still be te better solution
   if (myID == MASTER)
     {
+      mpi_send_stop (EARTH);	// stop workers
+    }
+  profile_tables (options, EARTH, &Gmax);
+#else
+#ifdef MPI /*WORKS*/
+    if (myID == MASTER)
+    {
 #endif
       profile_tables (options, EARTH, &Gmax);
 #ifdef MPI
     }
-#endif 
+#endif
 #endif /*SLOWNET*/
-  if (myID == MASTER)
+    if (myID == MASTER)
     {
       print_finish (EARTH, outfilepos);
       /* closing all files ------------------------------------------ */
@@ -288,11 +308,12 @@ main (int argc, char **argv)
     }
 #ifdef MPI
 #ifndef SLOWNET
-  mpi_send_stop (EARTH); // stop workers
+  mpi_send_stop (EARTH);	// stop workers
+  //  MPI_Barrier(MPI_COMM_WORLD);
 #endif
   MPI_Finalize ();
 #endif
-  apocalypse_now(EARTH);
+  apocalypse_now (EARTH);
   return 0;
 }				/* main end */
 
@@ -301,27 +322,32 @@ main (int argc, char **argv)
 void
 combine_loci (char type, option_fmt * options, world_fmt * world, long *Gmax)
 {
+  long kind = MULTILOCUS;
+  if (options->readsum)
+    {
+      if (world->loci == 1)
+	kind = SINGLELOCUS;
+    }
   if ((world->loci - world->skipped > 1) || (options->readsum))
     {
-      if(options->gamma)
+      if (options->gamma)
 	world->param0[world->numpop2] = world->options->alphavalue;
       world->repkind = set_repkind (options);
 #ifdef MPI
       if (myID == MASTER)
 	{
-	  mpi_gmax_master(world, Gmax);
+	  mpi_gmax_master (world, Gmax);
 #endif
 	  estimateParameter (options->replicatenum, *Gmax, world,
 			     options, world->cov[world->loci], 0 /*chain */ ,
-			     type, MULTILOCUS,
-			     world->repkind);	
+			     type, kind, world->repkind);
 #ifdef MPI
 	}
       else
 	{
-	  //	  printf("%i> before gmax worker\n",myID);
+	  //printf ("%i> before gmax worker\n", myID);
 	  mpi_gmax_worker (world);
-	  //	  printf("%i> start worker postlike calculations\n",myID);
+	  //printf ("%i> start worker postlike calculations\n", myID);
 	  mpi_maximize_worker (world, options->replicatenum);
 	}
 #endif
@@ -344,11 +370,12 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
 #endif
       get_data (data->infile, data, options);
 #ifdef MPI
-      numcpu = MIN(numcpu,data->loci+1);//manip global 
+      numcpu = MIN (numcpu, data->loci + 1);	//manip global 
       //broadcast_data_master(data,options);
-      if(numcpu==1)
+      if (numcpu == 1)
 	{
-	  error("This program was compiled to use a parallel computer\n and you tried to run it on only a single node.\nThis will not work because it uses a \n\"single_master-many_worker\" architecture \nand needs at least TWO nodes and TWO loci\n");
+	  error
+	    ("This program was compiled to use a parallel computer\n and you tried to run it on only a single node.\nThis will not work because it uses a \n\"single_master-many_worker\" architecture \nand needs at least TWO nodes and TWO loci\n");
 	}
     }
   else
@@ -387,12 +414,12 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
 #ifdef MPI
   if (myID == MASTER)
     {
-      mpi_runloci_master (data, EARTH->who);
+      mpi_runloci_master (data->loci, EARTH->who);
     }
   else
     {
       mpi_runloci_worker (universe, usize, options, data,
-			 &heating_pool, maxreplicate, &treefilepos, Gmax);
+			  &heating_pool, maxreplicate, &treefilepos, Gmax);
     }
   //  printf ("%i>         All loci run\n",myID);
 #else
@@ -400,17 +427,12 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
 	    &heating_pool, maxreplicate, &treefilepos, Gmax);
 #endif
 
-  /* save all genealogy-summaries --------------------------- */
-  if (myID==MASTER && options->writesum)
-    {
-      write_savesum (EARTH);
-    }
 #ifdef PTHREADS
   tpool_destroy (heating_pool, 1);
 #endif
-  if(options->heating)
+  if (options->heating)
     {
-      for(i=0;i<options->heated_chains;i++)
+      for (i = 0; i < options->heated_chains; i++)
 	{
 	  free_tree (universe[i]->root, universe[i]);
 	  free_timevector (universe[i]->treetimes);
@@ -540,8 +562,8 @@ run_locus (world_fmt ** universe, int usize, option_fmt * options,
 			    update_uepanc (EARTH);
 #endif
 			  heated_swap (universe, EARTH->options, &acc_vh,
-				       &acc_h, &acc_w, &acc_c, &vh, &h, &w, &jj,
-				       &j, &hot, &warm, &cold);
+				       &acc_h, &acc_w, &acc_c, &vh, &h, &w,
+				       &jj, &j, &hot, &warm, &cold);
 			}
 		      else
 			{
@@ -568,7 +590,8 @@ run_locus (world_fmt ** universe, int usize, option_fmt * options,
 		      advance_clone_like (SUN, vh, &SUN->G);
 		      for (ii = HEATED_CHAIN_NUM;
 			   ii < EARTH->options->heated_chains; ++ii)
-			advance_clone_like (universe[ii], universe[ii]->accept,
+			advance_clone_like (universe[ii],
+					    universe[ii]->accept,
 					    &(universe[ii])->G);
 		    }
 		  /* store condensed tree information
@@ -576,8 +599,8 @@ run_locus (world_fmt ** universe, int usize, option_fmt * options,
 #ifdef UEP
 		  store_uep (EARTH);
 #endif
-		  condense_time (EARTH, &step, &j, &accepted, &EARTH->G, &steps,
-				 oldsteps, rep);
+		  condense_time (EARTH, &step, &j, &accepted, &EARTH->G,
+				 &steps, oldsteps, rep);
 		  if (step > 0)
 		    advance_clone_like (EARTH, j, &EARTH->G);
 		}		// end steps
@@ -588,13 +611,13 @@ run_locus (world_fmt ** universe, int usize, option_fmt * options,
 		      sizeof (double) * EARTH->numpop2);
 	      log_param0 (EARTH->atl[rep][locus].param0,
 			  EARTH->atl[rep][locus].lparam0, EARTH->numpop2);
-	      copies2lcopies(&EARTH->atl[rep][locus]);
+	      copies2lcopies (&EARTH->atl[rep][locus]);
 	      EARTH->repkind = SINGLECHAIN;
 	      // single chain,  single replicate
 	      // estimateParameter(locus, rep, chain, type, 
 	      //                        EARTH, SINGLELOCUS);
 	      kind = SINGLELOCUS;
-	      *Gmax = (EARTH->G > *Gmax) ? EARTH->G+1 : (*Gmax) ;
+	      *Gmax = (EARTH->G > *Gmax) ? EARTH->G + 1 : (*Gmax);
 	      estimateParameter (rep, *Gmax, EARTH, options,
 				 EARTH->cov[locus], chain, type, kind,
 				 EARTH->repkind);
@@ -606,16 +629,15 @@ run_locus (world_fmt ** universe, int usize, option_fmt * options,
 				      increment, &acc_vh, &acc_h, &acc_w,
 				      &acc_c, &hot, &warm, &cold);
 	    }			//end chains
-	  change_chaintype (locus, &type, EARTH, &increment, &oldsteps, &chains,
-			    options);
+	  change_chaintype (locus, &type, EARTH, &increment, &oldsteps,
+			    &chains, options);
 	  /* evaluate multiple long chain estimates */
 	  if (runs < 0 && options->replicate && options->replicatenum == 0)
 	    {
 	      EARTH->repkind = MULTIPLECHAIN;
 	      estimateParameter (rep, *Gmax, EARTH, options,
 				 EARTH->cov[locus], chain, type,
-				 SINGLELOCUS,
-				 EARTH->repkind);
+				 SINGLELOCUS, EARTH->repkind);
 	    }
 	}			//end runs 
     }				//end replicates
@@ -632,6 +654,61 @@ run_locus (world_fmt ** universe, int usize, option_fmt * options,
     }
 }
 
+
+ /* save all genealogy-summaries --------------------------- */
+void
+get_treedata (world_fmt * world, option_fmt * options)
+{
+#ifdef MPI
+  long maxreplicate = (options->replicate
+		       && options->replicatenum >
+		       0) ? options->replicatenum : 1;
+#endif
+  if (myID == MASTER)
+    {
+      if (options->writesum)
+	{
+#ifdef MPI
+	  //get all sumfile data from the workers using unpack_result_buffer()
+	  mpi_results_master (MIGMPI_SUMFILE, world, maxreplicate,
+			      unpack_sumfile_buffer);
+#endif
+	  write_savesum (world);
+	}
+#ifdef SLOWNET
+      else
+	{
+	  mpi_results_master (MIGMPI_SUMFILE, world, maxreplicate,
+			      unpack_sumfile_buffer);
+	}
+#endif
+    }
+}
+
+ /* get all mig-histogram data --------------------------- */
+void
+get_mighistdata (world_fmt * world, option_fmt * options)
+{
+#ifdef MPI
+  long maxreplicate = (options->replicate
+		       && options->replicatenum >
+		       0) ? options->replicatenum : 1;
+#endif
+  if (myID == MASTER)
+    {
+      if (options->mighist)
+	{
+#ifdef MPI
+	  //get all mighist data from the workers using unpack_mighist_buffer()
+	  mpi_results_master (MIGMPI_MIGHIST, world, maxreplicate,
+			      unpack_mighist_buffer);
+#endif
+	}
+    }
+}
+
+
+
 void
 heated_swap (world_fmt ** universe, worldoption_fmt * options, double *acc_vh,
 	     double *acc_h, double *acc_w, double *acc_c, long *vh, long *h,
@@ -729,9 +806,9 @@ change_chaintype (long locus, char *type, world_fmt * world, long *increment,
 }
 
 void
-prepare_next_chain (world_fmt ** universe, worldoption_fmt * options, char type,
-		    long chain, long *chains, long *pluschain, long locus,
-		    long replicate)
+prepare_next_chain (world_fmt ** universe, worldoption_fmt * options,
+		    char type, long chain, long *chains, long *pluschain,
+		    long locus, long replicate)
 {
   long i;
   EARTH->likelihood[0] = EARTH->likelihood[EARTH->G];
@@ -766,8 +843,8 @@ prepare_next_chain (world_fmt ** universe, worldoption_fmt * options, char type,
 void
 print_heating_progress (world_fmt ** universe, worldoption_fmt * options,
 			long steps, long increment, double *acc_vh,
-			double *acc_h, double *acc_w, double *acc_c, long *hot,
-			long *warm, long *cold)
+			double *acc_h, double *acc_w, double *acc_c,
+			long *hot, long *warm, long *cold)
 {
   if (options->heating)
     {
@@ -812,7 +889,7 @@ long
 analyze_olddata (world_fmt * world,
 		 option_fmt * options, data_fmt * data, long *outfilepos)
 {
-  long Gmax=0;
+  long Gmax = 0;
   Gmax = read_savesum (world, options, data);
   synchronize_param (world, options);
   if (options->plot)
@@ -821,9 +898,21 @@ analyze_olddata (world_fmt * world,
       world->options->plotnow = TRUE;
     }
   world->locus = 0;
-  *outfilepos = print_title (world, options);
-  print_options (stdout, world, options, data);
-  print_options (world->outfile, world, options, data);
+  if (myID == MASTER)
+    {
+      *outfilepos = print_title (world, options);
+      print_options (stdout, world, options, data);
+      print_options (world->outfile, world, options, data);
+#ifdef MPI
+      mpi_runloci_master (world->loci, world->who);
+#endif
+    }
+#ifdef MPI
+  else
+    {
+      assignloci_worker (world);
+    }
+#endif
   return Gmax;
 }
 
@@ -848,9 +937,6 @@ profile_tables (option_fmt * options, world_fmt * world, long *gmaxptr)
 	      fflush (world->outfile);
 	    }
 	}
-#ifdef MPI
-      printf("will print percentile tables\n");
-#endif
       if (options->printprofsummary)
 	{
 	  print_profile_percentile (world);
@@ -893,13 +979,14 @@ setup_locus (long locus, world_fmt * world, option_fmt * options,
 	  data->seq->endsite += data->seq->addon;
 	}
     }
-  if (!options->replicate || (options->replicate && options->replicatenum == 0)
+  if (!options->replicate
+      || (options->replicate && options->replicatenum == 0)
       || (options->replicate && world->replicate == options->replicatenum))
     {
       //free_datapart (data, options, locus);
       if (data->skiploci[locus])
 	{			/* skip loci with no tips */
-	  //	  cleanup_world (world, locus);
+	  //      cleanup_world (world, locus);
 	  return 0;
 	}
     }
@@ -929,8 +1016,8 @@ setup_locus (long locus, world_fmt * world, option_fmt * options,
 }
 
 void
-condense_time (world_fmt * world, long *step, long *j, long *accepted, long *G,
-	       long *steps, long oldsteps, long rep)
+condense_time (world_fmt * world, long *step, long *j, long *accepted,
+	       long *G, long *steps, long oldsteps, long rep)
 {
   world->rep = rep;
   if (*step == 0)
