@@ -9,7 +9,14 @@
 
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
- $Id: sequence.c,v 1.33 2001/05/10 06:50:07 beerli Exp $
+<<<<<<< sequence.c
+ $Id: sequence.c,v 1.37 2001/07/25 19:27:24 beerli Exp $
+=======
+ 
+Copyright 2001 Peter Beerli and Joseph Felsenstein
+>>>>>>> 1.34
+
+$Id: sequence.c,v 1.37 2001/07/25 19:27:24 beerli Exp $
 
 -------------------------------------------------------*/
 
@@ -19,8 +26,10 @@
 #include <dmalloc.h>
 #endif
 /* prototypes ------------------------------------------- */
-void make_sequences (world_fmt * world, option_fmt * options, data_fmt * data, long locus);
-void init_sequences (world_fmt * world, option_fmt * options, data_fmt * data, long locus);
+void make_sequences (world_fmt * world, option_fmt * options, data_fmt * data,
+		     long locus);
+void init_sequences (world_fmt * world, option_fmt * options, data_fmt * data,
+		     long locus);
 void init_sequences2 (world_fmt * world, seqmodel_fmt * seq, long locus);
 void initratio (option_fmt * options);
 void initfreqs (double *freqa, double *freqc, double *freqg, double *freqt);
@@ -28,37 +37,49 @@ void initcatn (long *categs);
 boolean initcategs (long categs, double *rate, double *probcat);
 void initprobcat (long categs, double *probsum, double *probcat);
 void init_tbl (world_fmt * world, long locus);
-void print_weights (FILE * outfile, world_fmt * world, option_fmt * options, long locus);
-void print_tbl (FILE * outfile, world_fmt * world, option_fmt * options, long locus);
+void print_weights (FILE * outfile, world_fmt * world, option_fmt * options,
+		    long locus);
+void print_tbl (FILE * outfile, world_fmt * world, option_fmt * options,
+		long locus);
 double treelike_seq (world_fmt * world, long locus);
 double treelike_snp (world_fmt * world, long locus);
 /*private functions */
 void getbasefreqs (option_fmt * options, seqmodel_fmt * seq, long locus);
-void empiricalfreqs (world_fmt * world, option_fmt * options, seqmodel_fmt * seq, long locus);
+void empiricalfreqs (world_fmt * world, option_fmt * options,
+		     seqmodel_fmt * seq, long locus);
 void makeweights (world_fmt * world, data_fmt * data, long locus);
-void makevalues_seq (world_fmt * world, option_fmt * options, data_fmt * data, long locus);
+void makevalues_seq (world_fmt * world, option_fmt * options, data_fmt * data,
+		     long locus);
 void make_invarsites (world_fmt * world, data_fmt * data, long locus);
-void make_invarsites_unlinked (world_fmt * world, data_fmt * data, long locus);
-void sitecombine2 (world_fmt * world, data_fmt * data, long sites, long locus);
+void make_invarsites_unlinked (world_fmt * world, data_fmt * data,
+			       long locus);
+void sitecombine2 (world_fmt * world, data_fmt * data, long sites,
+		   long locus);
 void sitesort2 (world_fmt * world, data_fmt * data, long sites, long locus);
 void sitescrunch2 (world_fmt * world, long sites, long i, long j, long locus);
-void inputoptions (world_fmt * world, option_fmt * options, data_fmt * data, long locus);
+void inputoptions (world_fmt * world, option_fmt * options, data_fmt * data,
+		   long locus);
 void inputweights (world_fmt * world, data_fmt * data, long chars);
-void inputcategs (long a, long b, world_fmt * world, option_fmt * options, data_fmt * data);
+void inputcategs (long a, long b, world_fmt * world, option_fmt * options,
+		  data_fmt * data);
 void initlambda (option_fmt * options);
-void printweights (FILE * outfile, world_fmt * world, option_fmt * options, short inc, long chars, short *weight, char *letters);
+void printweights (FILE * outfile, world_fmt * world, option_fmt * options,
+		   short inc, long chars, short *weight, char *letters);
 void print_seqfreqs (FILE * outfile, world_fmt * world, option_fmt * options);
 
-void snp_invariants (contribarr invariants, long endsite, long rcategs, seqmodel_fmt * seq, phenotype x1);
+void snp_invariants (contribarr invariants, long endsite, long rcategs,
+		     seqmodel_fmt * seq, phenotype x1);
 
-void makevalues_snp (world_fmt * world, option_fmt * options, data_fmt * data, long locus);
+void makevalues_snp (world_fmt * world, option_fmt * options, data_fmt * data,
+		     long locus);
 
-void init_sequences_aliases(world_fmt *world, option_fmt *options, data_fmt *data, long locus);
+void init_sequences_aliases (world_fmt * world, option_fmt * options,
+			     data_fmt * data, long locus);
 
 
 void check_basefreq (option_fmt * options);
 
-extern void swap(void *, void *);
+extern void swap (void *, void *);
 
 const short C = 1;
 const short G = 2;
@@ -67,7 +88,8 @@ const short T = 3;
 
 /* allocation things */
 void
-init_sequences (world_fmt * world, option_fmt * options, data_fmt * data, long locus)
+init_sequences (world_fmt * world, option_fmt * options, data_fmt * data,
+		long locus)
 {
   static boolean done = FALSE;
   long sites = world->data->seq->sites[locus];
@@ -78,23 +100,33 @@ init_sequences (world_fmt * world, option_fmt * options, data_fmt * data, long l
       done = TRUE;
       world->data->seq->alias = (long *) calloc (1, sizeof (long) * sites);
       world->data->seq->ally = (long *) calloc (1, sizeof (long) * sites);
-      world->data->seq->aliasweight = (long *) calloc (1, sizeof (long) * sites);
+      world->data->seq->aliasweight =
+	(long *) calloc (1, sizeof (long) * sites);
       world->data->seq->location = (long *) calloc (1, sizeof (long) * sites);
       world->data->seq->category = (long *) calloc (1, sizeof (long) * sites);
       world->data->seq->weight = (short *) calloc (1, sizeof (short) * sites);
     }
   else
     {
-      world->data->seq->alias = (long *) realloc (world->data->seq->alias, sizeof (long) * sites);
-      world->data->seq->ally = (long *) realloc (world->data->seq->ally, sizeof (long) * sites);
-      world->data->seq->aliasweight = (long *) realloc (world->data->seq->aliasweight, sizeof (long) * sites);
-      world->data->seq->location = (long *) realloc (world->data->seq->location, sizeof (long) * sites);
-      world->data->seq->category = (long *) realloc (world->data->seq->category, sizeof (long) * sites);
-      world->data->seq->weight = (short *) realloc (world->data->seq->weight, sizeof (short) * sites);
+      world->data->seq->alias =
+	(long *) realloc (world->data->seq->alias, sizeof (long) * sites);
+      world->data->seq->ally =
+	(long *) realloc (world->data->seq->ally, sizeof (long) * sites);
+      world->data->seq->aliasweight =
+	(long *) realloc (world->data->seq->aliasweight,
+			  sizeof (long) * sites);
+      world->data->seq->location =
+	(long *) realloc (world->data->seq->location, sizeof (long) * sites);
+      world->data->seq->category =
+	(long *) realloc (world->data->seq->category, sizeof (long) * sites);
+      world->data->seq->weight =
+	(short *) realloc (world->data->seq->weight, sizeof (short) * sites);
     }
 }
 
-void init_sequences_aliases(world_fmt *world, option_fmt *options, data_fmt *data, long locus)
+void
+init_sequences_aliases (world_fmt * world, option_fmt * options,
+			data_fmt * data, long locus)
 {
   inputoptions (world, options, data, locus);
   if (!options->freqsfrom)
@@ -110,14 +142,16 @@ initratio (option_fmt * options)
   long z = 0;
   char *tmp;
   char input[LINESIZE];
-  printf ("Transition/transversion ratio?\nEnter a value for each locus, spaced by blanks or commas\n");
-  fgets (input, LINESIZE, stdin);
+  printf
+    ("Transition/transversion ratio?\nEnter a value for each locus, spaced by blanks or commas\n");
+  FGETS (input, LINESIZE, stdin);
   tmp = strtok (input, " ,\n");
   while (tmp != NULL)
     {
       options->ttratio[z++] = atof (tmp);
       tmp = strtok (NULL, " ,;\n");
-      options->ttratio = (double *) realloc (options->ttratio, sizeof (double) * (z + 1));
+      options->ttratio =
+	(double *) realloc (options->ttratio, sizeof (double) * (z + 1));
       options->ttratio[z] = 0.0;
     }
 }
@@ -129,17 +163,19 @@ initfreqs (double *freqa, double *freqc, double *freqg, double *freqt)
   int scanned;
   double summ = 0;
 
-  printf ("Base frequencies for A, C, G, T/U\n (use blanks to separate, if all are equal use a sign [=])?\n");
+  printf
+    ("Base frequencies for A, C, G, T/U\n (use blanks to separate, if all are equal use a sign [=])?\n");
   for (;;)
     {
-      fgets (input, LINESIZE, stdin);
+      FGETS (input, LINESIZE, stdin);
       if (input[0] == '=')
 	{
 	  scanned = 4;
 	  *freqa = *freqc = *freqg = *freqt = 0.25;
 	}
       else
-	scanned = sscanf (input, "%lf%lf%lf%lf%*[^\n]", freqa, freqc, freqg, freqt);
+	scanned =
+	  sscanf (input, "%lf%lf%lf%lf%*[^\n]", freqa, freqc, freqg, freqt);
       if (scanned == 4)
 	break;
       else
@@ -153,7 +189,8 @@ initfreqs (double *freqa, double *freqc, double *freqg, double *freqt)
   *freqc /= summ;
   *freqg /= summ;
   *freqt /= summ;
-  printf ("Nucleotide frequencies: A=%f, C=%f, G=%f, T=%f\n", *freqa, *freqc, *freqg, *freqt);
+  printf ("Nucleotide frequencies: A=%f, C=%f, G=%f, T=%f\n", *freqa, *freqc,
+	  *freqg, *freqt);
 }
 
 
@@ -171,8 +208,9 @@ initcatn (long *categs)
 }
 
 
-boolean initcategs (long categs, double *rate, double *probcat)
-{				/* initialize rate categories*/
+boolean
+initcategs (long categs, double *rate, double *probcat)
+{				/* initialize rate categories */
   long i;
   char input[LINESIZE];
   char rest[LINESIZE];
@@ -181,8 +219,9 @@ boolean initcategs (long categs, double *rate, double *probcat)
 
   for (;;)
     {
-      printf ("Either enter the Shape parameter alpha for Gamma deviated rates\n*OR* enter the rates for each category (use a space to separate)\n");
-      fgets (input, LINESIZE, stdin);
+      printf
+	("Either enter the Shape parameter alpha for Gamma deviated rates\n*OR* enter the rates for each category (use a space to separate)\n");
+      FGETS (input, LINESIZE, stdin);
       done = TRUE;
       if (count_words (input) == 1)
 	{
@@ -192,7 +231,8 @@ boolean initcategs (long categs, double *rate, double *probcat)
       for (i = 0; i < categs; i++)
 	{
 	  scanned = sscanf (input, "%lf %[^\n]", &rate[i], rest);
-	  if ((scanned < 2 && i < (categs - 1)) || (scanned < 1 && i == (categs - 1)))
+	  if ((scanned < 2 && i < (categs - 1))
+	      || (scanned < 1 && i == (categs - 1)))
 	    {
 	      printf ("Please enter exactly %ld values.\n", categs);
 	      done = FALSE;
@@ -220,12 +260,13 @@ initprobcat (long categs, double *probsum, double *probcat)
     {
       printf ("Probability for each category?");
       printf (" (use a space to separate)\n");
-      fgets (input, LINESIZE, stdin);
+      FGETS (input, LINESIZE, stdin);
       done = TRUE;
       for (i = 0; i < categs; i++)
 	{
 	  scanned = sscanf (input, "%lf %[^\n]", &probcat[i], rest);
-	  if ((scanned < 2 && i < (categs - 1)) || (scanned < 1 && i == (categs - 1)))
+	  if ((scanned < 2 && i < (categs - 1))
+	      || (scanned < 1 && i == (categs - 1)))
 	    {
 	      done = FALSE;
 	      printf ("Please enter exactly %ld values.\n", categs);
@@ -256,7 +297,8 @@ initprobcat (long categs, double *probsum, double *probcat)
 /*data read material ===================================== */
 
 void
-make_sequences (world_fmt * world, option_fmt * options, data_fmt * data, long locus)
+make_sequences (world_fmt * world, option_fmt * options, data_fmt * data,
+		long locus)
 {
   makevalues_seq (world, options, data, locus);
   if (options->freqsfrom)
@@ -267,7 +309,8 @@ make_sequences (world_fmt * world, option_fmt * options, data_fmt * data, long l
 }
 
 void
-make_snp (world_fmt * world, option_fmt * options, data_fmt * data, long locus)
+make_snp (world_fmt * world, option_fmt * options, data_fmt * data,
+	  long locus)
 {
   makevalues_snp (world, options, data, locus);
   /*if (options->freqsfrom)
@@ -313,7 +356,9 @@ getbasefreqs (option_fmt * options, seqmodel_fmt * seq, long locus)
   seq->freqcy = seq->freqc / seq->freqy;
   seq->freqgr = seq->freqg / seq->freqr;
   seq->freqty = seq->freqt / seq->freqy;
-  aa = seq->ttratio * (seq->freqr) * (seq->freqy) - seq->freqa * seq->freqg - seq->freqc * seq->freqt;
+  aa =
+    seq->ttratio * (seq->freqr) * (seq->freqy) - seq->freqa * seq->freqg -
+    seq->freqc * seq->freqt;
   bb = seq->freqa * (seq->freqgr) + seq->freqc * (seq->freqty);
   seq->xi = aa / (aa + bb);
   seq->xv = 1.0 - seq->xi;
@@ -323,11 +368,24 @@ getbasefreqs (option_fmt * options, seqmodel_fmt * seq, long locus)
       printf (" is impossible with these base frequencies!\n");
       seq->xi = 0.0;
       seq->xv = 1.0;
-      seq->ttratio = (seq->freqa * seq->freqg + seq->freqc * seq->freqt) / ((seq->freqr) * (seq->freqy));
+      seq->ttratio =
+	(seq->freqa * seq->freqg +
+	 seq->freqc * seq->freqt) / ((seq->freqr) * (seq->freqy));
       printf (" Transition/transversion parameter reset\n");
-      printf ("  so transition/transversion ratio is %10.6f\n\n", (seq->ttratio));
+      printf ("  so transition/transversion ratio is %10.6f\n\n",
+	      (seq->ttratio));
     }
-  seq->fracchange = (seq->xi) * (2 * seq->freqa * (seq->freqgr) + 2 * seq->freqc * (seq->freqty)) + (seq->xv) * (1.0 - seq->freqa * seq->freqa - seq->freqc * seq->freqc - seq->freqg * seq->freqg - seq->freqt * seq->freqt);
+  seq->fracchange =
+    (seq->xi) * (2 * seq->freqa * (seq->freqgr) +
+		 2 * seq->freqc * (seq->freqty)) + (seq->xv) * (1.0 -
+								seq->freqa *
+								seq->freqa -
+								seq->freqc *
+								seq->freqc -
+								seq->freqg *
+								seq->freqg -
+								seq->freqt *
+								seq->freqt);
 }
 
 /*===================================================*/
@@ -356,7 +414,8 @@ makeweights (world_fmt * world, data_fmt * data, long locus)
   for (i = 1; i <= world->data->seq->endsite; i++)
     {
       world->data->seq->location[world->data->seq->alias[i - 1] - 1] = i;
-      world->data->seq->ally[world->data->seq->alias[i - 1] - 1] = world->data->seq->alias[i - 1];
+      world->data->seq->ally[world->data->seq->alias[i - 1] - 1] =
+	world->data->seq->alias[i - 1];
     }
   init_sequences2 (world, world->data->seq, locus);
 }				/* makeweights */
@@ -365,14 +424,18 @@ void
 init_sequences2 (world_fmt * world, seqmodel_fmt * seq, long locus)
 {
   if (locus == 0)
-    world->contribution = (contribarr *) malloc (seq->endsite * sizeof (contribarr));
+    world->contribution =
+      (contribarr *) malloc (seq->endsite * sizeof (contribarr));
   else
-    world->contribution = (contribarr *) realloc (world->contribution, seq->endsite * sizeof (contribarr));
+    world->contribution =
+      (contribarr *) realloc (world->contribution,
+			      seq->endsite * sizeof (contribarr));
 }
 
 
 void
-makevalues_seq (world_fmt * world, option_fmt * options, data_fmt * data, long locus)
+makevalues_seq (world_fmt * world, option_fmt * options, data_fmt * data,
+		long locus)
 {
   long i, ii, j, k, l, pop;
   long b;
@@ -508,13 +571,15 @@ makevalues_seq (world_fmt * world, option_fmt * options, data_fmt * data, long l
 
 
 void
-makevalues_snp (world_fmt * world, option_fmt * options, data_fmt * data, long locus)
+makevalues_snp (world_fmt * world, option_fmt * options, data_fmt * data,
+		long locus)
 {
   long i, ii, j, k, l, pop;
   long b, f;
   node **treenode = world->nodep;
   f = world->data->seq->addon;
-  for (k = 0; k < world->data->seq->endsite * (world->data->seq->addon + 1); k += (1 + world->data->seq->addon))
+  for (k = 0; k < world->data->seq->endsite * (world->data->seq->addon + 1);
+       k += (1 + world->data->seq->addon))
     {
       j = world->data->seq->alias[k / (world->data->seq->addon + 1)] - 1;
       i = -1;
@@ -537,7 +602,8 @@ makevalues_snp (world_fmt * world, option_fmt * options, data_fmt * data, long l
 		      // reset all values for the snp columns
 		      for (b = 1; b <= 4; b++)
 			{
-			  memset (treenode[i]->x.s[k + b][l], 0, sizeof (double) * 4);
+			  memset (treenode[i]->x.s[k + b][l], 0,
+				  sizeof (double) * 4);
 			  treenode[i]->x.s[k + b][l][b - 1] = 1.0;
 			}
 		      continue;
@@ -545,7 +611,8 @@ makevalues_snp (world_fmt * world, option_fmt * options, data_fmt * data, long l
 		  else
 		    {
 		      for (b = 0; b <= 4; b++)
-			memset (treenode[i]->x.s[k + b][l], 0, sizeof (double) * 4);
+			memset (treenode[i]->x.s[k + b][l], 0,
+				sizeof (double) * 4);
 		    }
 
 		  switch (data->yy[pop][ii][locus][0][j])
@@ -858,9 +925,20 @@ sitesort2 (world_fmt * world, data_fmt * data, long sites, long locus)
 	    {
 	      jj = seq->alias[j - 1];
 	      jg = seq->alias[j + gap - 1];
-	      samewt = ((seq->weight[jj - 1] != 0) && (seq->weight[jg - 1] != 0)) || ((seq->weight[jj - 1] == 0) && (seq->weight[jg - 1] == 0));
-	      tied = samewt && (seq->category[jj - 1] == seq->category[jg - 1]);
-	      flip = ((!samewt) && (seq->weight[jj - 1] == 0)) || (samewt && (seq->category[jj - 1] > seq->category[jg - 1]));
+	      samewt = ((seq->weight[jj - 1] != 0)
+			&& (seq->weight[jg - 1] != 0))
+		|| ((seq->weight[jj - 1] == 0) && (seq->weight[jg - 1] == 0));
+	      tied = samewt
+		&& (seq->category[jj - 1] == seq->category[jg - 1]);
+	      flip = ((!samewt) && (seq->weight[jj - 1] == 0)) || (samewt
+								   &&
+								   (seq->
+								    category
+								    [jj - 1] >
+								    seq->
+								    category
+								    [jg -
+								     1]));
 	      k = 0;
 	      pop = 0;
 	      kk = -1;
@@ -875,8 +953,12 @@ sitesort2 (world_fmt * world, data_fmt * data, long sites, long locus)
 		    {
 		      kk++;
 		    }
-		  flip = (data->yy[temppop[pop]][kk][locus][0][jj - 1] > data->yy[temppop[pop]][kk][locus][0][jg - 1]);
-		  tied = (tied && data->yy[temppop[pop]][kk][locus][0][jj - 1] == data->yy[temppop[pop]][kk][locus][0][jg - 1]);
+		  flip =
+		    (data->yy[temppop[pop]][kk][locus][0][jj - 1] >
+		     data->yy[temppop[pop]][kk][locus][0][jg - 1]);
+		  tied = (tied
+			  && data->yy[temppop[pop]][kk][locus][0][jj - 1] ==
+			  data->yy[temppop[pop]][kk][locus][0][jg - 1]);
 		  k++;
 		}
 	      if (!flip)
@@ -928,8 +1010,13 @@ sitecombine2 (world_fmt * world, data_fmt * data, long sites, long locus)
       tied = TRUE;
       while (j <= sites && tied)
 	{
-	  samewt = ((seq->aliasweight[i - 1] != 0) && (seq->aliasweight[j - 1] != 0)) || ((seq->aliasweight[i - 1] == 0) && (seq->aliasweight[j - 1] == 0));
-	  tied = samewt && (seq->category[seq->alias[i - 1] - 1] == seq->category[seq->alias[j - 1] - 1]);
+	  samewt = ((seq->aliasweight[i - 1] != 0)
+		    && (seq->aliasweight[j - 1] != 0))
+	    || ((seq->aliasweight[i - 1] == 0)
+		&& (seq->aliasweight[j - 1] == 0));
+	  tied = samewt
+	    && (seq->category[seq->alias[i - 1] - 1] ==
+		seq->category[seq->alias[j - 1] - 1]);
 	  k = 0;
 	  pop = 0;
 	  kk = -1;
@@ -944,7 +1031,12 @@ sitecombine2 (world_fmt * world, data_fmt * data, long sites, long locus)
 		{
 		  kk++;
 		}
-	      tied = (tied && data->yy[temppop[pop]][kk][locus][0][seq->alias[i - 1] - 1] == data->yy[temppop[pop]][kk][locus][0][seq->alias[j - 1] - 1]);
+	      tied = (tied
+		      && data->yy[temppop[pop]][kk][locus][0][seq->
+							      alias[i - 1] -
+							      1] ==
+		      data->yy[temppop[pop]][kk][locus][0][seq->alias[j - 1] -
+							   1]);
 	      k++;
 	    }
 	  if (!tied)
@@ -1010,7 +1102,8 @@ sitescrunch2 (world_fmt * world, long sites, long i, long j, long locus)
 }				/* sitescrunch2 */
 
 void
-inputoptions (world_fmt * world, option_fmt * options, data_fmt * data, long locus)
+inputoptions (world_fmt * world, option_fmt * options, data_fmt * data,
+	      long locus)
 {
   long i;
   long sites = world->data->seq->sites[locus];
@@ -1062,7 +1155,8 @@ inputweights (world_fmt * world, data_fmt * data, long chars)
 }				/* inputweights */
 
 void
-inputcategs (long a, long b, world_fmt * world, option_fmt * options, data_fmt * data)
+inputcategs (long a, long b, world_fmt * world, option_fmt * options,
+	     data_fmt * data)
 {
   /* input the categories, 1-9 */
   char ch;
@@ -1076,7 +1170,8 @@ inputcategs (long a, long b, world_fmt * world, option_fmt * options, data_fmt *
     }
   ungetc (ch, data->catfile);
   fscanf (data->catfile, "%ld", &options->categs);
-  options->rate = (double *) realloc (options->rate, sizeof (double) * options->categs);
+  options->rate =
+    (double *) realloc (options->rate, sizeof (double) * options->categs);
   for (i = 0; i < options->categs; i++)
     {
       fscanf (data->catfile, "%lf", &options->rate[i]);
@@ -1095,7 +1190,9 @@ inputcategs (long a, long b, world_fmt * world, option_fmt * options, data_fmt *
 	world->data->seq->category[i] = ch - '0';
       else
 	{
-	  printf ("BAD CATEGORY CHARACTER: %c -- CATEGORIES ARE CURRENTLY 1-%ld\n", ch, world->options->categs);
+	  printf
+	    ("BAD CATEGORY CHARACTER: %c -- CATEGORIES ARE CURRENTLY 1-%ld\n",
+	     ch, world->options->categs);
 	  exit (EXIT_FAILURE);
 	}
     }
@@ -1105,7 +1202,8 @@ inputcategs (long a, long b, world_fmt * world, option_fmt * options, data_fmt *
 
 
 void
-empiricalfreqs (world_fmt * world, option_fmt * options, seqmodel_fmt * seq, long locus)
+empiricalfreqs (world_fmt * world, option_fmt * options, seqmodel_fmt * seq,
+		long locus)
 {
   /* Get empirical base frequencies from the data */
   long i, j, k;
@@ -1130,10 +1228,14 @@ empiricalfreqs (world_fmt * world, option_fmt * options, seqmodel_fmt * seq, lon
 	      summ += (options->freqc) * world->nodep[i]->x.s[j][0][C];
 	      summ += (options->freqg) * world->nodep[i]->x.s[j][0][G];
 	      summ += (options->freqt) * world->nodep[i]->x.s[j][0][T];
-	      suma += w * (options->freqa) * world->nodep[i]->x.s[j][0][0] / summ;
-	      sumc += w * (options->freqc) * world->nodep[i]->x.s[j][0][C] / summ;
-	      sumg += w * (options->freqg) * world->nodep[i]->x.s[j][0][G] / summ;
-	      sumt += w * (options->freqt) * world->nodep[i]->x.s[j][0][T] / summ;
+	      suma +=
+		w * (options->freqa) * world->nodep[i]->x.s[j][0][0] / summ;
+	      sumc +=
+		w * (options->freqc) * world->nodep[i]->x.s[j][0][C] / summ;
+	      sumg +=
+		w * (options->freqg) * world->nodep[i]->x.s[j][0][G] / summ;
+	      sumt +=
+		w * (options->freqt) * world->nodep[i]->x.s[j][0][T] / summ;
 	    }
 	}
       summ = suma + sumc + sumg + sumt;
@@ -1150,7 +1252,8 @@ initlambda (option_fmt * options)
 {
   while (options->lambda <= 1.0)
     {
-      printf ("Mean block length of sites having the same rate\n (needs to be greater than 1)?\n");
+      printf
+	("Mean block length of sites having the same rate\n (needs to be greater than 1)?\n");
       scanf ("%lf%*[^\n]", &options->lambda);
       getchar ();
     }
@@ -1178,16 +1281,22 @@ init_tbl (world_fmt * world, long locus)
     {
       for (j = 0; j < categs; j++)
 	{
-	  world->tbl[i][j]->rat = world->options->rrate[i] * world->options->rate[j];
-	  world->tbl[i][j]->ratxi = world->tbl[i][j]->rat * world->data->seq->xi;
-	  world->tbl[i][j]->ratxv = world->tbl[i][j]->rat * world->data->seq->xv;
+	  world->tbl[i][j]->rat =
+	    world->options->rrate[i] * world->options->rate[j];
+	  world->tbl[i][j]->ratxi =
+	    world->tbl[i][j]->rat * world->data->seq->xi;
+	  world->tbl[i][j]->ratxv =
+	    world->tbl[i][j]->rat * world->data->seq->xv;
 	}
     }
   sumrates = 0.0;
   for (i = 0; i < world->data->seq->endsite; i++)
     {
       for (j = 0; j < rcategs; j++)
-	sumrates += world->data->seq->aliasweight[i] * world->options->probcat[j] * world->tbl[j][world->data->seq->category[world->data->seq->alias[i] - 1] - 1]->rat;
+	sumrates +=
+	  world->data->seq->aliasweight[i] * world->options->probcat[j] *
+	  world->tbl[j][world->data->seq->
+			category[world->data->seq->alias[i] - 1] - 1]->rat;
     }
   sumrates /= (double) world->data->seq->sites[locus];
   for (i = 0; i < rcategs; i++)
@@ -1200,19 +1309,23 @@ init_tbl (world_fmt * world, long locus)
 }				/* inittable */
 
 void
-print_weights (FILE * outfile, world_fmt * world, option_fmt * options, long locus)
+print_weights (FILE * outfile, world_fmt * world, option_fmt * options,
+	       long locus)
 {
   if (options->weights)
     {
       if ((options->printdata) || (options->progress && outfile == stdout))
 	{
-	  printweights (outfile, world, options, 0, world->data->seq->sites[locus], world->data->seq->weight, "Sites");
+	  printweights (outfile, world, options, 0,
+			world->data->seq->sites[locus],
+			world->data->seq->weight, "Sites");
 	}
     }
 }
 
 void
-print_tbl (FILE * outfile, world_fmt * world, option_fmt * options, long locus)
+print_tbl (FILE * outfile, world_fmt * world, option_fmt * options,
+	   long locus)
 {
   long i;
 
@@ -1225,10 +1338,13 @@ print_tbl (FILE * outfile, world_fmt * world, option_fmt * options, long locus)
       fprintf (outfile, "\nRegion type     Rate of change    Probability\n");
       fprintf (outfile, "---------------------------------------------\n");
       for (i = 0; i < opt->rcategs; i++)
-	fprintf (outfile, "%9ld%16.3f%17.3f\n", i + 1, opt->rrate[i], opt->probcat[i]);
+	fprintf (outfile, "%9ld%16.3f%17.3f\n", i + 1, opt->rrate[i],
+		 opt->probcat[i]);
       putc ('\n', outfile);
       if (opt->autocorr)
-	fprintf (outfile, "Expected length of a patch of sites having the same rate = %8.3f\n", 1. / opt->lambda);
+	fprintf (outfile,
+		 "Expected length of a patch of sites having the same rate = %8.3f\n",
+		 1. / opt->lambda);
       putc ('\n', outfile);
     }
   if (opt->categs > 1)
@@ -1244,7 +1360,8 @@ print_tbl (FILE * outfile, world_fmt * world, option_fmt * options, long locus)
 
 
 void
-printweights (FILE * outfile, world_fmt * world, option_fmt * options, short inc, long chars, short *weight, char *letters)
+printweights (FILE * outfile, world_fmt * world, option_fmt * options,
+	      short inc, long chars, short *weight, char *letters)
 {
   /* print out the weights of sites */
   long i, j;
@@ -1274,13 +1391,19 @@ print_seqfreqs (FILE * outfile, world_fmt * world, option_fmt * options)
       if (options->freqsfrom)
 	fprintf (outfile, "\nEmpirical ");
       fprintf (outfile, "Base Frequencies\n");
-      fprintf (outfile, "------------------------------------------------------------\n");
-      fprintf (outfile, "Locus     Nucleotide                        Transition/\n");
-      fprintf (outfile, "          ------------------------------  Transversion ratio\n");
+      fprintf (outfile,
+	       "------------------------------------------------------------\n");
+      fprintf (outfile,
+	       "Locus     Nucleotide                        Transition/\n");
+      fprintf (outfile,
+	       "          ------------------------------  Transversion ratio\n");
       fprintf (outfile, "          A       C       G       T(U)\n");
-      fprintf (outfile, "------------------------------------------------------------\n");
+      fprintf (outfile,
+	       "------------------------------------------------------------\n");
     }
-  fprintf (outfile, "%4li      %6.4f  %6.4f  %6.4f  %6.4f    %10.5f\n", world->locus + 1, options->freqa, options->freqc, options->freqg, options->freqt, world->data->seq->ttratio);
+  fprintf (outfile, "%4li      %6.4f  %6.4f  %6.4f  %6.4f    %10.5f\n",
+	   world->locus + 1, options->freqa, options->freqc, options->freqg,
+	   options->freqt, world->data->seq->ttratio);
   if (outfile == stdout)
     fprintf (outfile, "\n");
 
@@ -1312,8 +1435,10 @@ treelike_seq (world_fmt * world, long locus)
 	{
 	  x1 = &(p->x.s[i][0]);
 	  scale = p->scale[i];
-	  tterm[0] = seq->freqa * (*x1)[0] + seq->freqc * (*x1)[1] + seq->freqg * (*x1)[2] + seq->freqt * (*x1)[3];
-	  summ += seq->aliasweight[i] * (log (tterm[0]) + scale) ;
+	  tterm[0] =
+	    seq->freqa * (*x1)[0] + seq->freqc * (*x1)[1] +
+	    seq->freqg * (*x1)[2] + seq->freqt * (*x1)[3];
+	  summ += seq->aliasweight[i] * (log (tterm[0]) + scale);
 	}
     }
   else
@@ -1325,7 +1450,9 @@ treelike_seq (world_fmt * world, long locus)
 	  for (j = 0; j < opt->rcategs; j++)
 	    {
 	      x1 = &(p->x.s[i][j]);
-	      tterm[j] = seq->freqa * (*x1)[0] + seq->freqc * (*x1)[1] + seq->freqg * (*x1)[2] + seq->freqt * (*x1)[3];
+	      tterm[j] =
+		seq->freqa * (*x1)[0] + seq->freqc * (*x1)[1] +
+		seq->freqg * (*x1)[2] + seq->freqt * (*x1)[3];
 	    }
 	  sumterm = 0.0;
 	  for (j = 0; j < opt->rcategs; j++)
@@ -1333,8 +1460,8 @@ treelike_seq (world_fmt * world, long locus)
 	  lterm = log (sumterm) + scale;
 	  for (j = 0; j < opt->rcategs; j++)
 	    clai[j] = tterm[j] / sumterm;
-	  swap(clai, world->contribution[i]);
-	  //	  memcpy (world->contribution[i], clai, size);
+	  swap (clai, world->contribution[i]);
+	  //      memcpy (world->contribution[i], clai, size);
 	  summ += seq->aliasweight[i] * lterm;
 	}
       for (j = 0; j < opt->rcategs; j++)
@@ -1348,7 +1475,7 @@ treelike_seq (world_fmt * world, long locus)
 	  if ((seq->ally[i] > 0) && (seq->location[seq->ally[i] - 1] > 0))
 	    {
 	      lai = seq->location[seq->ally[i] - 1];
-	      swap(world->contribution[lai-1], clai);
+	      swap (world->contribution[lai - 1], clai);
 	      //memcpy (clai, world->contribution[lai - 1], size);
 	      for (j = 0; j < opt->rcategs; j++)
 		nulike[j] = ((1.0 - opt->lambda) * like[j] + sumc) * clai[j];
@@ -1358,7 +1485,7 @@ treelike_seq (world_fmt * world, long locus)
 	      for (j = 0; j < opt->rcategs; j++)
 		nulike[j] = ((1.0 - opt->lambda) * like[j] + sumc);
 	    }
-	  swap(nulike, like);
+	  swap (nulike, like);
 	  //memcpy (like, nulike, size);
 	}
       sum2 = 0.0;
@@ -1370,7 +1497,8 @@ treelike_seq (world_fmt * world, long locus)
 }				/* treelikelihood */
 
 void
-snp_invariants (contribarr invariants, long endsite, long rcategs, seqmodel_fmt * seq, phenotype x1)
+snp_invariants (contribarr invariants, long endsite, long rcategs,
+		seqmodel_fmt * seq, phenotype x1)
 {
   long i, j;
   memset (invariants, 0, sizeof (contribarr));
@@ -1378,7 +1506,9 @@ snp_invariants (contribarr invariants, long endsite, long rcategs, seqmodel_fmt
     {
       for (j = 0; j < rcategs; j++)
 	{
-	  invariants[j] += (seq->freqa * x1[i][j][0] + seq->freqc * x1[i][j][1] + seq->freqg * x1[i][j][2] + seq->freqt * x1[i][j][3]);
+	  invariants[j] +=
+	    (seq->freqa * x1[i][j][0] + seq->freqc * x1[i][j][1] +
+	     seq->freqg * x1[i][j][2] + seq->freqt * x1[i][j][3]);
 	}
     }
   for (j = 0; j < rcategs; j++)
@@ -1410,7 +1540,9 @@ treelike_snp (world_fmt * world, long locus)
       for (j = 0; j < opt->rcategs; j++)
 	{
 	  x1 = &(p->x.s[i][j]);
-	  tterm[j] = (seq->freqa * (*x1)[0] + seq->freqc * (*x1)[1] + seq->freqg * (*x1)[2] + seq->freqt * (*x1)[3]) / invariants[j];
+	  tterm[j] =
+	    (seq->freqa * (*x1)[0] + seq->freqc * (*x1)[1] +
+	     seq->freqg * (*x1)[2] + seq->freqt * (*x1)[3]) / invariants[j];
 	}
       sumterm = 0.0;
       for (j = 0; j < opt->rcategs; j++)
@@ -1433,14 +1565,16 @@ treelike_snp (world_fmt * world, long locus)
 	{
 	  lai = seq->location[seq->ally[i] - 1];
 	  for (j = 0; j < opt->rcategs; j++)
-	    nulike[j] = ((1.0 - opt->lambda) * like[j] + sumc) * world->contribution[lai - 1][j];
+	    nulike[j] =
+	      ((1.0 - opt->lambda) * like[j] +
+	       sumc) * world->contribution[lai - 1][j];
 	}
       else
 	{
 	  for (j = 0; j < opt->rcategs; j++)
 	    nulike[j] = ((1.0 - opt->lambda) * like[j] + sumc);
 	}
-      swap(nulike,like);
+      swap (nulike, like);
       //memcpy (like, nulike, size);
     }
   sum2 = 0.0;
@@ -1475,7 +1609,9 @@ treelike_snp_unlinked (world_fmt * world, long locus)
       ii = i / 5;
       x1 = &(p->x.s[i][0]);
       scale = p->scale[i];
-      tterm[0] = (seq->freqa * (*x1)[0] + seq->freqc * (*x1)[1] + seq->freqg * (*x1)[2] + seq->freqt * (*x1)[3]);
+      tterm[0] =
+	(seq->freqa * (*x1)[0] + seq->freqc * (*x1)[1] +
+	 seq->freqg * (*x1)[2] + seq->freqt * (*x1)[3]);
       if (i % 5 == 0)
 	{
 	  lterm = log (tterm[0]) + scale;
@@ -1485,7 +1621,8 @@ treelike_snp_unlinked (world_fmt * world, long locus)
       else
 	summ += pow (tterm[0], (double) seq->aliasweight[ii]);
       if (((i + 1) % 5) == 0 && i != 0)
-	result += datasum + log ((1 - exp (log (summ) - datasum)) / invariants[0]);
+	result +=
+	  datasum + log ((1 - EXP (log (summ) - datasum)) / invariants[0]);
     }
   return result;
 }				/* treelike_snp_unlinked */
@@ -1494,7 +1631,8 @@ void
 check_basefreq (option_fmt * options)
 {
 
-  if (options->freqa == 0. || options->freqc == 0. || options->freqt == 0. || options->freqg == 0.)
+  if (options->freqa == 0. || options->freqc == 0. || options->freqt == 0.
+      || options->freqg == 0.)
     {
       options->freqa = 0.25;
       options->freqc = 0.25;
@@ -1504,14 +1642,15 @@ check_basefreq (option_fmt * options)
 }
 
 
-void copy_seq(world_fmt *original, world_fmt *kopie)
+void
+copy_seq (world_fmt * original, world_fmt * kopie)
 {
   long sites;
   seqmodel_fmt *kseq;
   seqmodel_fmt *oseq;
   kseq = kopie->data->seq;
   oseq = original->data->seq;
-  sites  = oseq->sites[original->locus];
+  sites = oseq->sites[original->locus];
   kseq->freqa = oseq->freqa;
   kseq->freqt = oseq->freqt;
   kseq->freqg = oseq->freqg;
@@ -1529,13 +1668,13 @@ void copy_seq(world_fmt *original, world_fmt *kopie)
   kseq->xv = oseq->xv;
   kseq->ttratio = oseq->ttratio;
   kseq->fracchange = oseq->fracchange;
-  memcpy(kseq->sites, oseq->sites, sizeof(long)*original->loci);
-  memcpy(kseq->alias, oseq->alias, sizeof(long) * sites);
-  memcpy(kseq->ally, oseq->ally,  sizeof(long) * sites);
-  memcpy(kseq->category, oseq->category, sizeof(long)* sites);
-  memcpy(kseq->weight, oseq->weight, sizeof(short)*sites);
+  memcpy (kseq->sites, oseq->sites, sizeof (long) * original->loci);
+  memcpy (kseq->alias, oseq->alias, sizeof (long) * sites);
+  memcpy (kseq->ally, oseq->ally, sizeof (long) * sites);
+  memcpy (kseq->category, oseq->category, sizeof (long) * sites);
+  memcpy (kseq->weight, oseq->weight, sizeof (short) * sites);
   kseq->weightsum = oseq->weightsum;
-  memcpy(kseq->aliasweight, oseq->aliasweight, sizeof(long)*sites);
-  memcpy(kseq->location, oseq->location, sizeof(long)*sites);
+  memcpy (kseq->aliasweight, oseq->aliasweight, sizeof (long) * sites);
+  memcpy (kseq->location, oseq->location, sizeof (long) * sites);
   kseq->addon = oseq->addon;
 }
